@@ -2,6 +2,8 @@
 #'
 #' @param overwrite logical. Should the function overwrite existing files with
 #' the same name? (defaults to `FALSE`).
+#' @param metadata logical (defaults to `TRUE`). Should metadata be exported as
+#' well? They will be exported in csv files will the `_metadata.csv` suffix.
 #'
 #' @inheritParams lr_get_spec
 #'
@@ -12,9 +14,8 @@
 #'
 #' @section Warning:
 #'
-#' This step loses all metadata associated to the spectra. This metadata is
-#' critical to ensure reproducibility. We recommended you use
-#' [lr_get_metadata()] to extract this information from your raw data.
+#' When `metadata = TRUE`, if **either** the data **or** metadata export fails,
+#' nothing will be returned for this file.
 #'
 #' @importFrom tools file_path_sans_ext
 #' @importFrom utils write.csv
@@ -23,14 +24,9 @@
 #'
 #' @export
 lr_convert_tocsv <- function(where = NULL, ext = "txt", decimal = ".",
-                             sep = NULL, subdir = FALSE, cores = NULL,
-                             ignore.case = TRUE, overwrite = FALSE) {
-
-  if (!missing(cores)) {
-    warning("'cores' argument is deprecated. See ?future::plan for more info ",
-            "about how you can choose your parallelisation strategy.",
-            call. = FALSE)
-  }
+                             sep = NULL, subdir = FALSE,
+                             ignore.case = TRUE, overwrite = FALSE,
+                             metadata = TRUE) {
 
   if (is.null(where)) {
     warning("Please provide a valid location to read and write the files.",
@@ -61,7 +57,7 @@ lr_convert_tocsv <- function(where = NULL, ext = "txt", decimal = ".",
     tmp <- future_lapply(files, function(x) {
       p()
       tryCatch(spec2csv_single(x, decimal = decimal, sep = sep,
-                               overwrite = overwrite),
+                               overwrite = overwrite, metadata = metadata),
                error = function(e) NULL)
     })
   })
@@ -84,18 +80,30 @@ lr_convert_tocsv <- function(where = NULL, ext = "txt", decimal = ".",
 }
 
 #' @noRd
-spec2csv_single <- function(filename, decimal, sep, overwrite = FALSE) {
+spec2csv_single <- function(filename, decimal, sep, overwrite, metadata) {
 
-  data <- dispatch_parser(filename, decimal = decimal, sep = sep)[[1]]
+  exported <- dispatch_parser(filename, decimal = decimal, sep = sep)
 
-  csv_name <- paste0(file_path_sans_ext(filename), ".csv")
+  csv_name_data <- paste0(file_path_sans_ext(filename), ".csv")
+  csv_name_metadata <- paste0(file_path_sans_ext(filename), "_metadata.csv")
 
-  if (file.exists(csv_name) && !overwrite) {
-    stop(csv_name, " already exists. Select `overwrite = TRUE` to overwrite.")
+  if (file.exists(csv_name_data) && !overwrite) {
+    stop(
+      csv_name_data, " already exists. Select `overwrite = TRUE` to overwrite.",
+      call. = FALSE
+    )
+  }
+  if (metadata && file.exists(csv_name_metadata) && !overwrite) {
+    stop(
+      csv_name_metadata,
+      " already exists. Select `overwrite = TRUE` to overwrite.",
+      call. = FALSE
+    )
   }
 
-  write.csv(data, csv_name, row.names = FALSE)
+  write.csv(exported[[1]], csv_name_data, row.names = FALSE)
+  write.csv(exported[[2]], csv_name_metadata, row.names = FALSE)
 
-  invisible(csv_name)
+  invisible(csv_name_data)
 
 }
